@@ -4,7 +4,7 @@
 # Start Date:   Sat, 24 Aug 1996 23:45:34 +0200
 # Project:      INN
 # File:         innshellvars.tcl
-# RCSId:        $Id: innshellvars.tcl.in,v 1.6 2002/09/16 17:38:03 rra Exp $
+# RCSId:        $Id: innshellvars.tcl.in 7466 2005-12-12 03:04:08Z eagle $
 # Description:  Set up any and all variables that an INN tcl script
 #               might need.
 
@@ -77,6 +77,8 @@ set inn_inndf "${inn_newsbin}/inndf"
 set inn_egrep "/usr/bin/egrep"
 set inn_sort "/usr/bin/sort"
 set inn_getftp "/usr/bin/wget"
+set inn_uux "/usr/bin/uux"
+
 set inn_compress "/usr/bin/compress"
 set inn_gzip "/usr/bin/gzip"
 set inn_uncompress "/usr/bin/compress -d"
@@ -99,3 +101,5 @@ set inn_spooltemp "$inn_pathtmp"
 scan "02" "%o" inn_umask
 
 set env(PATH) "$inn_newslbin:$inn_newsbin:$env(PATH):/bin:/usr/bin:/usr/ucb"
+
+set env(HOME) "$inn_pathnews"
